{"": "", "SSL client authentication": "", "Generate a self-signed certificate": "", "Could not save config": "", "New address": "", "Could not load authentication provider list": "", "Add": "", "Save": "", "This might take a few seconds": "", "Allow sudo elevation for logged in users": "", "Generating certificate": "", "Restart panel": "", "New certificate": "", "Machine name": "", "Download certificate": "", "Generate": "", "Certificate generation failed": "", "New e-mail address": "", "E-mail authentication": "", "Language": "", "Settings": "", "Color tag": "", "Country": "", "New client certificate": "", "Self-signed certificate": "", "Remove": "", "Certificate successfully generated": "", "Host / IP": "", "No certificates are created yet.": "", "Please wait": "", "Deny other means of authentication": "", "Organization": "", "Could not load config": "", "No e-mail addresses added yet.": "", "E-mail address": "", "User to log in": "", "SSL client certificates": "", "Sudo": "", "Binding": "", "State": "", "Enable SSL": "", "Save and Close": "", "Authentication provider": "", "SSL certificate file": "", "Cancel": "", "Login as": "", "Common name": "", "Saved": "", "Port": "", "Enable client authentication": "", "Socket path": ""}